Documentation
¶
Index ¶
Constants ¶
const ( EnumParamFoo = "foo" EnumParamBar = "bar" EnumParamBaz = "baz" )
Variables ¶
This section is empty.
Functions ¶
Types ¶
type App ¶
type App struct {
AppName string
DatabasePath string
ViperCfg *viper.Viper
Logger *log.Logger
// contains filtered or unexported fields
}
App gives the global persistent state for the application Example fields
func (*App) Init ¶
Init() initializes the application state Other methods are best structured in their own files
Click to show internal directories.
Click to hide internal directories.